radontea documentation
======================
Radontea is a Python 3 library for computerized tomographic
image reconstruction. Radontea implements several iterative
and non-iterative reconstruction algorithms.
This is the documentaion of radontea version |release|.

.. toctree::
   :maxdepth: 4
   :caption: Contents:

   introduction
   code_reference
   examples


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
   

